@@ -31,7 +31,7 @@ class lines:
 
 	def plot_line(self, X, Y, title, xlabel, ylabel, imgText=None, outpath=None, 
 					subplot=None, xlim=None, ylim=None, xTextShift=0.05, yTextShift=0.95,
-					xTextLoc=None, yTextLoc=None):
+					xTextLoc=None, yTextLoc=None, color='blue'):
 		"""create a default 2D line plot
 		
 		: X: (float) the values for x-axis
@@ -46,7 +46,7 @@ class lines:
 		if X is None: X = np.arange(1, len(Y)+1)
 		if subplot is not None: plt.subplot(subplot)
 
-		self.add_plot(X,Y)
+		self.add_plot(X,Y, color)
 		self.set_title(title, fontsize=self.title_font)
 		self.set_xlabel(xlabel, fontsize=self.xfont)
 		self.set_ylabel(ylabel, fontsize=self.yfont)
